Task: Conversational Question Answering Challenge
==================================================
Description: CoQA is a large-scale dataset for building Conversational Question Answering systems. The goal of the CoQA challenge is to measure the ability of machines to understand a text passage and answer a series of interconnected questions that appear in a conversation. CoQA is pronounced as coca . See https://arxiv.org/abs/1808.07042

Tags: #COQA, #All, #QA

